
#line 2 "<stdout>"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#ifdef _LIBC
#include "namespace.h"
#endif
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/*	$NetBSD: flexint.h,v 1.3 2018/12/23 16:27:17 christos Exp $	*/

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE yylex.
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-yylineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                yy_size_t yyl;\
                for ( yyl = n; yyl < yyleng; ++yyl )\
                    if ( yytext[yyl] == '\n' )\
                        --yylineno;\
            }while(0)
    #define YY_LINENO_REWIND_TO(dst) \
            do {\
                const char *p;\
                for ( p = yy_cp-1; p >= (dst); --p)\
                    if ( *p == '\n' )\
                        --yylineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static yy_size_t yy_n_chars;		/* number of characters read into yy_ch_buf */
yy_size_t yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, yy_size_t size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, yy_size_t len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

#define yywrap() (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (yy_size_t)(yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 113
#define YY_END_OF_BUFFER 114
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[707] =
    {   0,
      111,  111,    0,    0,    0,    0,  114,  112,  112,  112,
      110,  111,   21,  111,  111,  111,  111,  111,  111,  112,
      112,  112,  112,  112,  112,  112,  112,  112,  112,  112,
      112,  112,  112,  112,  112,  112,  112,  112,  112,    5,
        4,    5,    9,    8,    9,    0,    0,    0,    1,  111,
       21,   22,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   11,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   23,    0,   23,   22,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   10,    0,    0,    3,    0,    3,
        7,    0,    7,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   33,    0,   27,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   58,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   83,    0,
        0,   28,    0,    0,    0,    0,   30,   93,    0,    0,
        0,    0,    6,    0,    0,    0,    0,    0,    0,    0,
        0,   12,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   31,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,   44,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   99,    0,    0,    0,    0,  100,    0,   95,
        0,    0,    0,    0,    0,    0,   25,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   84,   85,    0,
        0,    0,    0,   24,   32,    0,    0,    0,    0,   26,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   14,

       16,   17,   18,   19,   20,    0,    0,    0,  105,  104,
        0,  109,    0,    0,    0,    0,    0,    0,    0,    0,
       97,  101,   98,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   96,    0,    0,    0,    0,    0,   76,
        0,    0,    0,    0,    0,    0,    0,    0,   63,    0,
        0,    0,    0,   86,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    2,    0,
       13,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  102,    0,    0,    0,    0,   29,    0,   42,
        0,    0,    0,    0,   74,    0,    0,    0,    0,    0,

       71,    0,   70,    0,    0,    0,    0,   43,    0,    0,
        0,   90,    0,    0,    0,    0,    0,   49,    0,    0,
        0,   94,    0,    0,    0,    0,  107,    0,  106,   40,
       82,   80,    0,   81,   79,    0,  103,   34,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   68,    0,
        0,    0,    0,    0,   73,    0,    0,    0,    0,   87,
       41,    0,    0,    0,    0,    0,    0,   91,   45,    0,
        0,   15,  108,    0,    0,    0,    0,    0,   59,    0,
        0,    0,    0,   67,    0,    0,   62,    0,   75,    0,
        0,    0,   89,    0,    0,    0,    0,    0,    0,    0,

        0,    0,   92,    0,    0,    0,    0,    0,    0,    0,
        0,   60,    0,    0,    0,    0,    0,    0,    0,    0,
       88,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,   78,   77,   35,    0,   36,   61,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   37,    0,    0,    0,    0,
        0,    0,    0,   39,    0,   50,    0,   54,    0,    0,
        0,    0,    0,    0,   38,    0,   69,    0,    0,   66,
        0,    0,    0,    0,    0,   57,   47,   46,    0,   53,
        0,   65,    0,    0,   51,    0,   55,    0,   72,   64,

       52,   56,    0,    0,   48,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    4,    5,    1,    1,    1,    1,    6,
        7,    1,    1,    8,    9,   10,    1,   11,   12,   13,
       14,   15,   16,   11,   11,   11,   11,   17,   18,    1,
        1,    1,    1,    1,   19,   19,   20,   19,   19,   19,
       19,   19,   19,   19,   19,   21,   22,   23,   19,   19,
       19,   19,   24,   19,   19,   19,   19,   19,   19,   19,
        1,   25,    1,    1,   26,    1,   27,   28,   29,   30,

       31,   32,   33,   34,   35,    1,   36,   37,   38,   39,
       40,   41,   42,   43,   44,   45,   46,   47,   48,   49,
       50,   51,   52,   53,   54,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[55] =
    {   0,
        1,    1,    1,    2,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1
    } ;

static const flex_int16_t yy_base[713] =
    {   0,
        0,   53,   53,   55,   57,   61,  785,  786,  759,  780,
      786,   57,  772,   73,  741,  740,  739,  738,  743,   53,
      726,  744,   63,  731,  734,  741,   27,   53,  731,  729,
       64,  738,  723,   59,   68,  732,  735,   94,   75,  786,
      786,  740,  786,  786,  739,   93,  108,  760,  786,    0,
      752,  108,  722,  731,  729,  736,  722,  711,  720,  725,
       84,  716,  715,   86,  714,  710,  704,  698,  708,  719,
      699,  718,  786,   80,  700,  693,   90,  704,  690,  694,
       99,  699,  694,  697,  691,  125,   99,  685,  694,  127,
      134,  128,  136,  786,  137,  138,  135,  687,  695,  142,

      703,  697,  702,  689,  689,  134,  698,  688,  679,  691,
      675,  679,  682,  672,  686,  138,  685,  685,  670,  135,
      671,  677,  684,  672,  680,  675,  680,  669,  668,  665,
      672,  657,  665,  669,  786,  668,  669,  786,  162,  163,
      786,  164,  165,  654,  674,  673,  672,  671,  670,  669,
      646,  644,  141,  662,  656,  163,  643,  639,  639,  652,
      641,  637,  643,  635,  637,  634,  182,  786,  138,  786,
      645,  635,  643,  638,  631,  625,  630,  631,  641,  636,
      636,  620,  633,  632,  618,  623,  616,  616,  629,  620,
      616,  628,  627,  626,  625,  624,  623,  613,  626,  616,

      617,  605,  604,  612,  602,  611,  614,  599,  148,  607,
      606,  601,  595,  607,  596,  592,  604,  604,  583,  599,
      583,  146,  598,  143,  165,  576,  595,  583,  582,  170,
      173,  581,  587,  584,  592,  569,  584,  582,  162,  583,
      574,  786,  571,  177,  584,  575,  786,  583,  573,  572,
      565,  578,  786,  558,  566,  558,  557,  556,  555,  554,
      553,  786,  569,  558,  554,  546,  553,  547,  550,  558,
      182,  543,  544,  549,  553,  557,  550,  541,  536,  535,
      538,  535,  193,  544,  533,  786,  546,  547,  533,  534,
      542,  533,  526,  533,  527,  518,  518,  529,  519,  517,

      526,  525,  519,  786,  528,  519,  517,  510,  520,  522,
      517,  513,  506,  505,  196,  517,  502,  499,  195,  514,
      499,  516,  504,  511,  518,  503,  502,  501,  500,  499,
      498,  489,  501,  492,  499,  498,  493,  489,  489,  196,
      201,  480,  786,  487,  478,  479,  487,  786,  485,  786,
      493,  491,  480,  485,  475,  477,  786,  482,  467,  474,
      467,  471,  471,  476,  466,  460,  465,  472,  471,  457,
      455,  452,  469,  452,  458,  450,  454,  193,  786,  448,
      460,  458,  450,  786,  786,  450,  448,  444,  447,  786,
      454,  444,  443,  443,  437,  451,  452,  447,  450,  786,

      786,  786,  786,  786,  786,  440,  430,  439,  786,  786,
      422,  786,  445,  434,  441,  425,  431,  438,  422,  425,
      786,  786,  786,  419,  423,  209,  424,  426,  412,  424,
      418,  426,  430,  786,  410,  427,  422,  407,  405,  786,
      415,  406,  401,  416,  419,  410,  408,  414,  786,  408,
      411,  409,  404,  786,  393,  403,  389,  390,  395,  406,
      387,  405,  393,  390,  383,  393,  395,  399,  786,  380,
      786,  392,  390,  390,  370,  382,  375,  376,  379,  372,
      373,  375,  786,  373,  371,  379,  374,  786,  379,  786,
      368,  365,  366,  359,  786,  364,  376,  370,  359,  367,

      786,  363,  786,  354,  365,  345,  360,  786,  358,  360,
      358,  786,  345,  358,  357,  336,  347,  359,  341,  343,
      337,  786,  343,  354,  350,  342,  786,  327,  786,  786,
      786,  786,  349,  786,  786,  348,  786,  786,  328,  338,
      342,  335,  325,  328,  342,  332,  336,  333,  786,  338,
      313,  331,  316,  312,  786,  329,  326,  312,  322,  786,
      786,  312,  323,  309,  207,  321,  308,  786,  786,  306,
      309,  786,  786,  319,  318,  307,  312,  299,  786,  312,
      292,  290,  302,  786,  299,  294,  786,  289,  786,  295,
      304,  299,  786,  288,  305,  288,  295,  289,  288,  300,

      288,  281,  786,  287,  280,  291,  290,  275,  285,  284,
      274,  786,  276,  284,  285,  265,  271,  271,  266,  278,
      786,  279,  267,  275,  266,  269,  264,  275,  266,  265,
      256,  786,  786,  786,  253,  786,  786,  257,  256,  249,
      259,  253,  249,  255,  247,  244,  244,  248,   43,   36,
       75,   71,   92,  114,  146,  786,  169,  170,  185,  194,
      199,  202,  207,  786,  218,  786,  209,  786,  210,  216,
      213,  228,  229,  232,  786,  217,  786,  234,  219,  786,
      225,  219,  223,  237,  231,  786,  786,  786,  225,  786,
      237,  786,  231,  242,  786,  231,  786,  238,  786,  786,

      786,  786,  236,  248,  786,  786,  277,  279,  281,  282,
      284,  285
    } ;

static const flex_int16_t yy_def[713] =
    {   0,
      706,    1,  707,  707,  708,  708,  706,  706,  709,  710,
      706,  706,   12,   12,   14,   14,   14,   14,   14,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  711,  706,  706,  712,  709,  709,  710,  706,   14,
       12,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  711,
      711,  712,  712,  706,  709,  709,  706,  706,  706,  706,

      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  711,  711,
      706,  712,  712,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,

      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,

      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,

      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,

      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,

      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,

      706,  706,  706,  706,  706,    0,  706,  706,  706,  706,
      706,  706
    } ;

static const flex_int16_t yy_nxt[841] =
    {   0,
        8,    8,    8,    9,   10,   11,   11,   11,   12,    8,
       13,   13,   13,   13,   13,   13,   11,   11,   14,   15,
       16,   17,   18,   19,    8,   14,   20,    8,   21,   22,
        8,   23,   24,    8,   25,   26,   27,   28,   29,   30,
       31,    8,   32,   33,   34,    8,    8,   35,   36,   37,
        8,   11,   11,   11,   38,   41,   42,   41,   42,   44,
       45,   69,   39,   44,   45,   50,   70,   51,   51,   51,
       51,   51,   51,  668,  669,   50,   50,   50,   50,   50,
       50,   58,   50,   50,   50,   50,   50,   50,   50,   62,
       75,   59,   71,   80,   82,   86,   94,   63,   76,   72,

       77,   81,   64,   87,  670,   88,  121,   83,   65,   89,
       95,   96,  106,  671,  111,  107,  125,   47,   97,   97,
       97,   97,   97,   97,  122,  130,   86,  108,  112,   88,
      138,  141,   47,   89,   87,  126,  139,  140,  142,  143,
       94,   94,  672,  673,  131,   97,   97,   97,   97,   97,
       97,   91,   93,  146,  147,  148,  149,  150,   91,  156,
       93,   47,   47,  167,  172,  138,  138,  141,  141,  233,
      200,  173,  287,  157,  273,  201,  674,  174,  202,  203,
      175,  168,  290,  204,  288,  234,   91,   91,   93,   93,
      208,  205,  291,  274,  209,  292,  298,  293,  310,  210,

      299,  211,  315,  300,  311,  212,  675,  213,  223,  340,
      224,  225,  226,  341,  316,  676,  227,  301,  228,  229,
      302,  353,  414,  392,  230,  231,  393,  417,  677,  452,
      386,  354,  232,  355,  387,  453,  356,  485,  678,  415,
      388,  679,  486,  416,  418,  598,  680,  599,  419,  600,
      601,  681,  682,  683,  684,  685,  487,  686,  687,  688,
      689,  690,  691,  692,  693,  694,  695,  696,  697,  698,
      699,  700,  701,  702,  703,  704,  705,   40,   40,   43,
       43,   46,   48,   48,   90,   92,  667,  666,  665,  664,
      663,  662,  661,  660,  659,  658,  657,  656,  655,  654,

      653,  652,  651,  650,  649,  648,  647,  646,  645,  644,
      643,  642,  641,  640,  639,  638,  637,  636,  635,  634,
      633,  632,  631,  630,  629,  628,  627,  626,  625,  624,
      623,  622,  621,  620,  619,  618,  617,  616,  615,  614,
      613,  612,  611,  610,  609,  608,  607,  606,  605,  604,
      603,  602,  597,  596,  595,  594,  593,  592,  591,  590,
      589,  588,  587,  586,  585,  584,  583,  582,  581,  580,
      579,  578,  577,  576,  575,  574,  573,  572,  571,  570,
      569,  568,  567,  566,  565,  564,  563,  562,  561,  560,
      559,  558,  557,  556,  555,  554,  553,  552,  551,  550,

      549,  548,  547,  546,  545,  544,  543,  542,  541,  540,
      539,  538,  537,  536,  535,  534,  533,  532,  531,  530,
      529,  528,  527,  526,  525,  524,  523,  522,  521,  520,
      519,  518,  517,  516,  515,  514,  513,  512,  511,  510,
      509,  508,  507,  506,  505,  504,  503,  502,  501,  500,
      499,  498,  497,  496,  495,  494,  493,  492,  491,  490,
      489,  488,  484,  483,  482,  481,  480,  479,  478,  477,
      476,  475,  474,  473,  472,  471,  470,  469,  468,  467,
      466,  465,  464,  463,  462,  461,  460,  459,  458,  457,
      456,  455,  454,  451,  450,  449,  448,  447,  446,  445,

      444,  443,  442,  441,  440,  439,  438,  437,  436,  435,
      434,  433,  432,  431,  430,  429,  428,  427,  426,  425,
      424,  423,  422,  421,  420,  413,  412,  411,  410,  409,
      408,  407,  406,  405,  404,  403,  402,  401,  400,  399,
      398,  397,  396,  395,  394,  391,  390,  389,  385,  384,
      383,  382,  381,  380,  379,  378,  377,  376,  375,  374,
      373,  372,  371,  370,  369,  368,  367,  366,  365,  364,
      363,  362,  361,  360,  359,  358,  357,  352,  351,  350,
      349,  348,  347,  346,  345,  344,  343,  342,  339,  338,
      337,  336,  335,  334,  333,  332,  331,  330,  329,  328,

      327,  326,  325,  324,  323,  322,  321,  320,  319,  318,
      317,  314,  313,  312,  309,  308,  307,  306,  305,  304,
      303,  297,  296,  295,  294,  289,  286,  285,  284,  283,
      282,  281,  280,  279,  278,  277,  276,  275,  272,  271,
      270,  269,  268,  267,  266,  265,  264,  263,  262,  261,
      260,  259,  258,  257,  256,  255,  254,  253,  252,  251,
      250,  249,  248,  247,  246,  245,  244,  243,  242,  241,
      240,  239,  238,  237,  236,  235,  222,  221,  220,  219,
      218,  217,   73,  216,  215,  214,  207,  206,  199,  198,
      197,  196,  195,  194,  193,  192,  191,  190,  189,  188,

      187,  186,  135,  185,  184,  183,  182,  181,  180,  179,
      178,  177,  176,  171,  170,  169,  166,  165,  164,  163,
      162,  161,  160,  159,  158,  155,  154,  153,  152,  151,
      145,  144,  137,  136,  135,  134,  133,  132,  129,  128,
      127,  124,  123,  120,  119,  118,  117,  116,  115,  114,
      113,  110,  109,  105,  104,  103,  102,  101,  100,   99,
       98,   52,   49,   93,   91,   85,   84,   79,   78,   74,
       73,   68,   67,   66,   61,   60,   57,   56,   55,   54,
       53,   52,   49,   47,  706,    7,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,

      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706
    } ;

static const flex_int16_t yy_chk[841] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    2,    3,    3,    4,    4,    5,
        5,   27,    2,    6,    6,   12,   27,   12,   12,   12,
       12,   12,   12,  649,  650,   12,   12,   12,   12,   12,
       12,   20,   12,   14,   14,   14,   14,   14,   14,   23,
       31,   20,   28,   34,   35,   38,   46,   23,   31,   28,

       31,   34,   23,   38,  651,   39,   74,   35,   23,   39,
       47,   47,   61,  652,   64,   61,   77,   46,   52,   52,
       52,   52,   52,   52,   74,   81,   86,   61,   64,   87,
       90,   92,   47,   87,   86,   77,   91,   91,   93,   93,
       95,   96,  653,  654,   81,   97,   97,   97,   97,   97,
       97,   90,   92,  100,  100,  100,  100,  100,   91,  106,
       93,   95,   96,  116,  120,  139,  140,  142,  143,  169,
      153,  120,  222,  106,  209,  153,  655,  120,  153,  153,
      120,  116,  224,  153,  222,  169,  139,  140,  142,  143,
      156,  153,  224,  209,  156,  225,  230,  225,  239,  156,

      230,  156,  244,  231,  239,  156,  657,  156,  167,  271,
      167,  167,  167,  271,  244,  658,  167,  231,  167,  167,
      231,  283,  340,  319,  167,  167,  319,  341,  659,  378,
      315,  283,  167,  283,  315,  378,  283,  426,  660,  340,
      315,  661,  426,  340,  341,  565,  662,  565,  341,  565,
      565,  663,  665,  667,  669,  670,  426,  671,  672,  673,
      674,  676,  678,  679,  681,  682,  683,  684,  685,  689,
      691,  693,  694,  696,  698,  703,  704,  707,  707,  708,
      708,  709,  710,  710,  711,  712,  648,  647,  646,  645,
      644,  643,  642,  641,  640,  639,  638,  635,  631,  630,

      629,  628,  627,  626,  625,  624,  623,  622,  620,  619,
      618,  617,  616,  615,  614,  613,  611,  610,  609,  608,
      607,  606,  605,  604,  602,  601,  600,  599,  598,  597,
      596,  595,  594,  592,  591,  590,  588,  586,  585,  583,
      582,  581,  580,  578,  577,  576,  575,  574,  571,  570,
      567,  566,  564,  563,  562,  559,  558,  557,  556,  554,
      553,  552,  551,  550,  548,  547,  546,  545,  544,  543,
      542,  541,  540,  539,  536,  533,  528,  526,  525,  524,
      523,  521,  520,  519,  518,  517,  516,  515,  514,  513,
      511,  510,  509,  507,  506,  505,  504,  502,  500,  499,

      498,  497,  496,  494,  493,  492,  491,  489,  487,  486,
      485,  484,  482,  481,  480,  479,  478,  477,  476,  475,
      474,  473,  472,  470,  468,  467,  466,  465,  464,  463,
      462,  461,  460,  459,  458,  457,  456,  455,  453,  452,
      451,  450,  448,  447,  446,  445,  444,  443,  442,  441,
      439,  438,  437,  436,  435,  433,  432,  431,  430,  429,
      428,  427,  425,  424,  420,  419,  418,  417,  416,  415,
      414,  413,  411,  408,  407,  406,  399,  398,  397,  396,
      395,  394,  393,  392,  391,  389,  388,  387,  386,  383,
      382,  381,  380,  377,  376,  375,  374,  373,  372,  371,

      370,  369,  368,  367,  366,  365,  364,  363,  362,  361,
      360,  359,  358,  356,  355,  354,  353,  352,  351,  349,
      347,  346,  345,  344,  342,  339,  338,  337,  336,  335,
      334,  333,  332,  331,  330,  329,  328,  327,  326,  325,
      324,  323,  322,  321,  320,  318,  317,  316,  314,  313,
      312,  311,  310,  309,  308,  307,  306,  305,  303,  302,
      301,  300,  299,  298,  297,  296,  295,  294,  293,  292,
      291,  290,  289,  288,  287,  285,  284,  282,  281,  280,
      279,  278,  277,  276,  275,  274,  273,  272,  270,  269,
      268,  267,  266,  265,  264,  263,  261,  260,  259,  258,

      257,  256,  255,  254,  252,  251,  250,  249,  248,  246,
      245,  243,  241,  240,  238,  237,  236,  235,  234,  233,
      232,  229,  228,  227,  226,  223,  221,  220,  219,  218,
      217,  216,  215,  214,  213,  212,  211,  210,  208,  207,
      206,  205,  204,  203,  202,  201,  200,  199,  198,  197,
      196,  195,  194,  193,  192,  191,  190,  189,  188,  187,
      186,  185,  184,  183,  182,  181,  180,  179,  178,  177,
      176,  175,  174,  173,  172,  171,  166,  165,  164,  163,
      162,  161,  160,  159,  158,  157,  155,  154,  152,  151,
      150,  149,  148,  147,  146,  145,  144,  137,  136,  134,

      133,  132,  131,  130,  129,  128,  127,  126,  125,  124,
      123,  122,  121,  119,  118,  117,  115,  114,  113,  112,
      111,  110,  109,  108,  107,  105,  104,  103,  102,  101,
       99,   98,   89,   88,   85,   84,   83,   82,   80,   79,
       78,   76,   75,   72,   71,   70,   69,   68,   67,   66,
       65,   63,   62,   60,   59,   58,   57,   56,   55,   54,
       53,   51,   48,   45,   42,   37,   36,   33,   32,   30,
       29,   26,   25,   24,   22,   21,   19,   18,   17,   16,
       15,   13,   10,    9,    7,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,

      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706
    } ;

/* Table of booleans, true if rule could match eol. */
static const flex_int32_t yy_rule_can_match_eol[114] =
    {   0,
1, 0, 1, 1, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0,     };

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "rclex.l"
#line 2 "rclex.l"
/*-
 * Copyright (c) 2001 Jordan DeLong
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the author nor the names of contributors may be
 *    used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
#include "wm.h"
#include "rcfile.tab.h"

/* directory that filenames w/o '/' are refering to */
char *filedir = NULL;

/* name of currently proccessing file */
char *filename = NULL;

/* are we in a forplug included file */
plugin_t *inside_forplug = NULL;

/*
 * entry in the stack of included files; saves all the data
 * for parsing at the point the include is started and restores
 * it on the way out.
 */
typedef struct {
	YY_BUFFER_STATE buffer_state;
	char		*filedir;
	char		*filename;
	int		lineno;
	plugin_t	*inside_forplug;
} incent_t;

/* stack of included files */
static incent_t include_stack[10];
static int include_stacknum = 0;

/* translate \" into " in a string from the rcfile */
static char *rclex_makestr(char *yytext, int yyleng) {
	char *str;
	int len, i;

	/* 
	 * make a copy of the string and chop the " chars.
	 * this copy gets free()'d elsewhere. (yyparse, etc)
	 * switch all the \" into ", \\n into '', and \\ into \
	 */
	str = strdup(&yytext[1]);
	if (!str)
		err(1, "couldn't get memory for string in rclex_makestr");
	len = yyleng - 1;
	str[--len] = '\0';
	for (i = 0; i < len; i++)
		if (str[i] == '\\') {
			if (++i >= len)
				break;
			switch (str[i]) {
			case '\n':
				str[i - 1] = '\n';
				memmove(&str[i - 1], &str[i + 1], len - i + 1);
				len -= 2;
				break;
			case '\"':
				str[i - 1] = '\"';
				memmove(&str[i], &str[i + 1], len - i);
				len--;
				break;
			case '\\':
				str[i - 1] = '\\';
				memmove(&str[i], &str[i + 1], len - i);
				len--;
				break;
			}
		}

	return str;
}

/* start input from new FILE * */
static int rclex_includef(FILE *file, char *incfile,
		char *newfn, plugin_t *forplug) {
	char *tmpstr;

	/* make sure they aren't nesting too deep */
	if (include_stacknum >= sizeof(include_stack) / sizeof(incent_t)) {
		warnx("includes nested too deeply, sorry.");
		return -1;
	}

	/* save all the information we need to save */
	include_stack[include_stacknum].buffer_state = YY_CURRENT_BUFFER;
	if ((tmpstr = strdup(filename)) == NULL)
		err(1, "strdup() failed while trying to include file");
	include_stack[include_stacknum].filename = tmpstr;
	if ((tmpstr = strdup(filedir)) == NULL)
		err(1, "strdup() failed while trying to include file");
	include_stack[include_stacknum].filedir = tmpstr;
	include_stack[include_stacknum].lineno = yylineno;
	include_stack[include_stacknum].inside_forplug = inside_forplug;
	include_stacknum++;

	/* set the values for line num and such for the new buff */
	yylineno = 1;
	strcpy(filename, newfn);
	tmpstr = strrchr(incfile, '/');
	if (tmpstr) {
		*(tmpstr + 1) = '\0';
		if (incfile[0] != '/')
			strncat(filedir, incfile, MAXPATHLEN - strlen(filedir));
		else
			snprintf(filedir, MAXPATHLEN, "%s", incfile);
	}
	inside_forplug = forplug;
	yyin = file;
	yy_switch_to_buffer(yy_create_buffer(yyin, YY_BUF_SIZE));
#ifndef INITIAL	/* hack; flex docs say INITIAL === 0 */
	BEGIN(0);
#else
	BEGIN(INITIAL);
#endif

	return 0;
}

/* begin parsing a new file; include it */
int rclex_include(char *incfile, plugin_t *forplug) {
	char newfn[MAXPATHLEN];
	FILE *file;

	/* do this kinda early so we can try to open it first */
	if (incfile[0] != '/')
		snprintf(newfn, MAXPATHLEN, "%s%s", filedir, incfile);
	else
		snprintf(newfn, MAXPATHLEN, "%s", incfile);

	/* try to open the file */
	file = fopen(newfn, "r");
	if (!file) {
		warnx("couldn't include %s", newfn);
		return -1;
	}

	/* start parsing it */
	if (rclex_includef(file, incfile, newfn, forplug) == -1) {
		fclose(file);
		return -1;
	}

	return 0;
}

#line 1067 "<stdout>"

#line 1069 "<stdout>"

#define INITIAL 0
#define INCLUDE 1
#define EXEC 2

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			yy_size_t yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		yy_size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 187 "rclex.l"


#line 1292 "<stdout>"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 707 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 786 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

		if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
			{
			yy_size_t yyl;
			for ( yyl = 0; yyl < yyleng; ++yyl )
				if ( yytext[yyl] == '\n' )
					
    yylineno++;
;
			}

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 189 "rclex.l"
/* eat commentary */
	YY_BREAK
/*
	 * rcfile directives
	 *
	 * .include - just like CPP #include
	 * .exec - run a program and parse it's output
	 */
case 2:
YY_RULE_SETUP
#line 198 "rclex.l"
BEGIN(INCLUDE);
	YY_BREAK
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
#line 199 "rclex.l"
{
	char *str;

	str = rclex_makestr(yytext, yyleng);
	rclex_include(str, inside_forplug);

	free(str);
}
	YY_BREAK
case 4:
/* rule 4 can match eol */
YY_RULE_SETUP
#line 207 "rclex.l"
BEGIN(INITIAL);
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 208 "rclex.l"
/* eat */
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 210 "rclex.l"
BEGIN(EXEC);
	YY_BREAK
case 7:
/* rule 7 can match eol */
YY_RULE_SETUP
#line 211 "rclex.l"
{
	FILE *file;
	char *str;
	int fd[2];

	str = rclex_makestr(yytext, yyleng);

	/*
	 * we make a pipe, and set it as the new yyin val, and
	 * so forth.
	 */
	if (pipe(fd) != 0) {
		warn("unable to make pipe for .exec include");
		free(str);
		YY_BREAK;
	}

	/* fork for our exec include */
	if (!fork()) {
		/* dup the write end to stdout */
		if (dup2(fd[1], STDOUT_FILENO) == -1) {
			warn("couldn't dup descriptor for .exec include");
			exit(1);
		}

		/* close the read end and the nondup'd write descriptor */
		close(fd[0]);
		close(fd[1]);

		execl(_PATH_BSHELL, "sh", "-c", str, NULL);
		exit(1);
	}

	/* now set up the include, close the write end in the parent */
	close(fd[1]);
	file = fdopen(fd[0], "r");
	rclex_includef(file, ".", str, inside_forplug);
	free(str);
}
	YY_BREAK
case 8:
/* rule 8 can match eol */
YY_RULE_SETUP
#line 250 "rclex.l"
BEGIN(INITIAL);
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 251 "rclex.l"
/* eat */
	YY_BREAK
/*
	 * data types
	 */
case 10:
YY_RULE_SETUP
#line 257 "rclex.l"
yylval.num = 1;			return BOOLVAL;
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 258 "rclex.l"
yylval.num = 0;			return BOOLVAL;
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 259 "rclex.l"
return NOMASK;
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 260 "rclex.l"
yylval.num = ShiftMask;		return MODIFIER;
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 261 "rclex.l"
yylval.num = LockMask;		return MODIFIER;
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 262 "rclex.l"
yylval.num = ControlMask;	return MODIFIER;
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 263 "rclex.l"
yylval.num = Mod1Mask;		return MODIFIER;
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 264 "rclex.l"
yylval.num = Mod2Mask;		return MODIFIER;
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 265 "rclex.l"
yylval.num = Mod3Mask;		return MODIFIER;
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 266 "rclex.l"
yylval.num = Mod4Mask;		return MODIFIER;
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 267 "rclex.l"
yylval.num = Mod5Mask;		return MODIFIER;
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 268 "rclex.l"
yylval.num = atoi(yytext);	return INTEGER;
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 269 "rclex.l"
yylval.flnum = atof(yytext);	return FLOAT;
	YY_BREAK
case 23:
/* rule 23 can match eol */
YY_RULE_SETUP
#line 270 "rclex.l"
{
	char *str;

	str = rclex_makestr(yytext, yyleng);
	if (!str) {
		warnx("can't get memory for string");
		YY_BREAK;
	}
	yylval.str = str;
	return STRING;
}
	YY_BREAK
/*
	 * keywords
	 */
case 24:
YY_RULE_SETUP
#line 286 "rclex.l"
return OPTIONS;
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 287 "rclex.l"
return FORPLUG;
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 288 "rclex.l"
return PLUGDAT;
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 289 "rclex.l"
return LOAD;
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 290 "rclex.l"
return PARAM;
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 291 "rclex.l"
return FPARAM;
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 292 "rclex.l"
return STYLE;
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 293 "rclex.l"
return GROUPS;
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 294 "rclex.l"
return PIXMAPS;
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 295 "rclex.l"
return KEYS;
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 296 "rclex.l"
return DECOR;
	YY_BREAK
/*
	 * options section
	 */
case 35:
YY_RULE_SETUP
#line 302 "rclex.l"
return DESKTOPCNT;
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 303 "rclex.l"
return DESKTOPWID;
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 304 "rclex.l"
return DESKTOPHEI;
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 305 "rclex.l"
return FULLSCRZOOM;
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 306 "rclex.l"
return MOUSEMOD;
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 307 "rclex.l"
return ANIMDELAY;
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 308 "rclex.l"
return OPAQUEMOVE;
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 309 "rclex.l"
return FOCUSNEW;
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 310 "rclex.l"
return LINEWIDTH;
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 311 "rclex.l"
return LINEFG;
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 312 "rclex.l"
return WANTMITSHM;
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 313 "rclex.l"
return WSPACESLIDE;
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 314 "rclex.l"
return RELRESIZE;
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 315 "rclex.l"
return XINCORRECT;
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 316 "rclex.l"
return PLACEMENT;
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 317 "rclex.l"
return PLACENONZEROS;
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 318 "rclex.l"
return PLACETRANS;
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 319 "rclex.l"
return PLACEINTERACT;
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 320 "rclex.l"
return INTERACTTIME;
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 321 "rclex.l"
yylval.num = PLACEMENT_NONE;	return PLACETYPE;
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 322 "rclex.l"
yylval.num = PLACEMENT_RANDOM;	return PLACETYPE;
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 323 "rclex.l"
yylval.num = PLACEMENT_POINTER;	return PLACETYPE;
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 324 "rclex.l"
yylval.num = PLACEMENT_SMART;	return PLACETYPE;
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 325 "rclex.l"
return FOCUS;
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 326 "rclex.l"
yylval.num = FOCUS_CLICK;	return FOCUSTYPE;
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 327 "rclex.l"
yylval.num = FOCUS_SLOPPY;	return FOCUSTYPE;
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 328 "rclex.l"
yylval.num = FOCUS_POINTER;	return FOCUSTYPE;
	YY_BREAK
/*
	 * keys section
	 */
case 62:
YY_RULE_SETUP
#line 334 "rclex.l"
yylval.num = KEY_ICONIFY;	return KEYNAME;
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 335 "rclex.l"
yylval.num = KEY_ZOOM;		return KEYNAME;
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 336 "rclex.l"
yylval.num = KEY_SWITCHDESK;	return KEYNAME;
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 337 "rclex.l"
yylval.num = KEY_MOVEVIEWPORT;	return KEYNAME;
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 338 "rclex.l"
yylval.num = KEY_SETVIEWPORT;	return KEYNAME;
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 339 "rclex.l"
yylval.num = KEY_COMMAND;	return KEYNAME;
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 340 "rclex.l"
yylval.num = KEY_DELETE;	return KEYNAME;
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 341 "rclex.l"
yylval.num = KEY_CYCLEFOCUS;	return KEYNAME;
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 342 "rclex.l"
yylval.num = KEY_RAISE;		return KEYNAME;
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 343 "rclex.l"
yylval.num = KEY_LOWER;		return KEYNAME;
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 344 "rclex.l"
yylval.num = KEY_DGROUPSWITCH;	return KEYNAME;
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 345 "rclex.l"
yylval.num = KEY_STICKY;	return KEYNAME;
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 346 "rclex.l"
yylval.num = KEY_ABORT;		return KEYNAME;
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 347 "rclex.l"
yylval.num = KEY_RESTART;	return KEYNAME;
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 348 "rclex.l"
yylval.num = KEY_EXIT;		return KEYNAME;
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 349 "rclex.l"
yylval.num = CF_FWS;		return CYCLETYPE;
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 350 "rclex.l"
yylval.num = CF_BWS;		return CYCLETYPE;
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 351 "rclex.l"
yylval.num = CF_FSCR;		return CYCLETYPE;
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 352 "rclex.l"
yylval.num = CF_BSCR;		return CYCLETYPE;
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 353 "rclex.l"
yylval.num = CF_FALL;		return CYCLETYPE;
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 354 "rclex.l"
yylval.num = CF_BALL;		return CYCLETYPE;
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 355 "rclex.l"
yylval.num = MV_UP;		return MVDIR;
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 356 "rclex.l"
yylval.num = MV_DOWN;		return MVDIR;
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 357 "rclex.l"
yylval.num = MV_LEFT;		return MVDIR;
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 358 "rclex.l"
yylval.num = MV_RIGHT;		return MVDIR;
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 359 "rclex.l"
yylval.num = MV_UPRIGHT;	return MVDIR;
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 360 "rclex.l"
yylval.num = MV_DOWNRIGHT;	return MVDIR;
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 361 "rclex.l"
yylval.num = MV_DOWNLEFT;	return MVDIR;
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 362 "rclex.l"
yylval.num = MV_UPLEFT;		return MVDIR;
	YY_BREAK
/*
	 * style section
	 */
case 91:
YY_RULE_SETUP
#line 368 "rclex.l"
return TITLEFONT;
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 369 "rclex.l"
return TITLECOLOR;
	YY_BREAK
/*
	 * groups section
	 */
case 93:
YY_RULE_SETUP
#line 375 "rclex.l"
return TITLE;
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 376 "rclex.l"
return TRANSIENT;
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 377 "rclex.l"
return DEFAULT;
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 378 "rclex.l"
return INTERNAL;
	YY_BREAK
/*
	 * decoration section
	 */
case 97:
YY_RULE_SETUP
#line 384 "rclex.l"
yylval.num = DA_FULL;		return DECTYPE;
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 385 "rclex.l"
yylval.num = DA_NEAR;		return DECTYPE;
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 386 "rclex.l"
yylval.num = DA_FAR;		return DECTYPE;
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 387 "rclex.l"
yylval.num = DE_TOP;		return DECEDGE;
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 388 "rclex.l"
yylval.num = DE_LEFT;		return DECEDGE;
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 389 "rclex.l"
yylval.num = DE_RIGHT;		return DECEDGE;
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 390 "rclex.l"
yylval.num = DE_BOTTOM;		return DECEDGE;
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 391 "rclex.l"
yylval.num = ACT_NONE;		return ACTION;
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 392 "rclex.l"
yylval.num = ACT_MOVE;		return ACTION;
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 393 "rclex.l"
yylval.num = ACT_RESIZE;	return ACTION;
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 394 "rclex.l"
yylval.num = ACT_DELETE;	return ACTION;
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 395 "rclex.l"
yylval.num = ACT_ICONIFY;	return ACTION;
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 396 "rclex.l"
yylval.num = ACT_ZOOM;		return ACTION;
	YY_BREAK
/*
	 * misc rules
	 */
case 110:
YY_RULE_SETUP
#line 402 "rclex.l"
return yytext[0];
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 403 "rclex.l"
yylval.str = strdup(yytext); return IDENT;
	YY_BREAK
case 112:
/* rule 112 can match eol */
YY_RULE_SETUP
#line 404 "rclex.l"
/* eat anything else */
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(INCLUDE):
case YY_STATE_EOF(EXEC):
#line 406 "rclex.l"
{
	plugin_t *plugin;

	/* close the yyin currently in use */
	fclose(yyin);

	/*
	 * come back out a level from the include; if this is
	 * all the way out we stop.
	 */
	if (--include_stacknum < 0)
		yyterminate();
	yy_delete_buffer(YY_CURRENT_BUFFER);
	yy_switch_to_buffer(include_stack[include_stacknum].buffer_state);

	/*
	 * we need to call init on plugins for the forplug stuff.  this is
	 * when we have included a file as a result of a forplug directive
	 * earlier on.
	 */
	plugin = inside_forplug;
	inside_forplug = include_stack[include_stacknum].inside_forplug;
	if (!inside_forplug && plugin) {
		if (plugin->init) {
			plugin_this = plugin;
			if (plugin->init(plugin) != PLUGIN_OK)
				plugin_unload(plugin);
			plugin_this = NULL;
		}
		plugin_subparams_free(&plugin->params);
	}

	/* set up the new file location strings and yylineno */
	snprintf(filedir, MAXPATHLEN, "%s", include_stack[include_stacknum].filedir);
	free(include_stack[include_stacknum].filedir);
	snprintf(filename, MAXPATHLEN, "%s", include_stack[include_stacknum].filename);
	free(include_stack[include_stacknum].filename);
	yylineno = include_stack[include_stacknum].lineno;
}
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 445 "rclex.l"
ECHO;
	YY_BREAK
#line 2061 "<stdout>"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	yy_size_t number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (yy_size_t) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (yy_size_t) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 707 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 707 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 706);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');
	if ( YY_CURRENT_BUFFER_LVALUE->yy_at_bol )
		
    yylineno++;
;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, yy_size_t  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	yy_size_t i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
yy_size_t yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    /* We do not touch yylineno unless the option is enabled. */
    yylineno =  1;
    
    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 445 "rclex.l"
